@@ -1,11 +1,19 @@
 import argparse
 import os
+from enum import Enum
 from typing import List, Optional, Tuple
 
 from accession import __version__
 from accession.accession import accession_factory
 from accession.cloud_tasks import QueueInfo
+from accession.database.connection import DbSession
+from accession.database.query import DbQuery
 from accession.metadata import parse_metadata_list
+from accession.subcommands.info import info
+
+
+class Subparsers(Enum):
+    Info = "info"
 
 
 def get_parser() -> argparse.ArgumentParser:
@@ -13,7 +21,7 @@ def get_parser() -> argparse.ArgumentParser:
         description="Accession pipeline outputs, \
                                                  download output metadata for scattering"
     )
-    metadata_group = parser.add_mutually_exclusive_group(required=True)
+    metadata_group = parser.add_mutually_exclusive_group()
     metadata_group.add_argument(
         "-m",
         "--accession-metadata",
@@ -30,7 +38,6 @@ def get_parser() -> argparse.ArgumentParser:
         type=str,
         default=None,
         help="the type of pipeline run being accessioned, e.g. mirna or long_read_rna",
-        required=True,
     )
     parser.add_argument(
         "-d",
@@ -48,11 +55,7 @@ def get_parser() -> argparse.ArgumentParser:
         help="Force accessioning to post files even if there is md5 duplication",
     )
     parser.add_argument(
-        "-s",
-        "--server",
-        default="dev",
-        help="Server the files will be accessioned to",
-        required=True,
+        "-s", "--server", default="dev", help="Server the files will be accessioned to"
     )
     parser.add_argument(
         "--no-log-file",
@@ -75,6 +78,38 @@ def get_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "-v", "--version", action="version", version="%(prog)s {}".format(__version__)
     )
+    subparsers = parser.add_subparsers(title="subcommands", dest="subcommand_name")
+    info_parser = subparsers.add_parser(
+        name=Subparsers.Info.value,
+        help="Obtain accessioning results in a tabular format",
+    )
+    info_parser.add_argument(
+        "ids",
+        help=(
+            "Zero or more experiment accessions or `@id`s, e.g. /experiments/ENCSR123ABC/"
+            "or ENCSR456DEF, Cromwell workflow IDs (can specify whole ID or only the "
+            "first few digits, a la `git`), `caper-str-label`s, or other Crowmell "
+            "workflow labels in key=value form, e.g. my-label=foo. These can be "
+            "combined in arbitrary fashion. If no filters are specified, then info "
+            "about all accessioning runs will be returned."
+        ),
+        nargs="*",
+    )
+    info_parser.add_argument(
+        "-d",
+        "--date",
+        help=(
+            "Can be either a single date or a range of dates. Dates should take the "
+            "form `MM`, `MM/DD` or `MM/DD/YY`, with zero-padding and year optional. If "
+            "the year is left out then the current year will be inserted "
+            "automatically. For example, `4/5`, `04/05`, and `4/5/20` are all "
+            "equivalent assuming it is 2020. To use a date range, either specify two "
+            "valid dates separated by a dash, e.g. `4/5-4/6` or `4-6`, specify one "
+            "date with a leading `\\-`, meaning search from the beginning of time to "
+            "the provided date, e.g. `\\-4/5/20`, or use a trailing dash to search "
+            "from the specifed date to the present."
+        ),
+    )
     return parser
 
 
@@ -102,14 +137,6 @@ def check_or_set_lab_award(lab: Optional[str], award: Optional[str]) -> Tuple[st
     return lab, award
 
 
-def get_queue_info_from_env() -> Optional[QueueInfo]:
-    name = os.environ.get("ACCESSION_CLOUD_TASKS_QUEUE_NAME")
-    region = os.environ.get("ACCESSION_CLOUD_TASKS_QUEUE_REGION")
-    if name is None or region is None:
-        return None
-    return QueueInfo(name=name, region=region)
-
-
 def get_metadatas_from_args(args: argparse.Namespace) -> List[str]:
     """
     If there was only one metadata file/label provided, then returns a list containing
@@ -128,20 +155,27 @@ def main() -> None:
     parser = get_parser()
     args = parser.parse_args()
     lab, award = check_or_set_lab_award(args.lab, args.award)
-    queue_info = get_queue_info_from_env()
-    metadatas = get_metadatas_from_args(args)
-    for metadata in metadatas:
-        accessioner = accession_factory(
-            args.pipeline_type,
-            metadata,
-            args.server,
-            lab,
-            award,
-            log_file_path=args.log_file_path,
-            no_log_file=args.no_log_file,
-            queue_info=queue_info,
-        )
-        accessioner.accession_steps(args.dry_run, force=args.force)
+    queue_info = QueueInfo.from_env()
+    if args.accession_metadata is not None or args.metadata_list is not None:
+        metadatas = get_metadatas_from_args(args)
+        for metadata in metadatas:
+            accessioner = accession_factory(
+                args.pipeline_type,
+                metadata,
+                args.server,
+                lab,
+                award,
+                log_file_path=args.log_file_path,
+                no_log_file=args.no_log_file,
+                queue_info=queue_info,
+            )
+            if accessioner.cloud_tasks_upload_client is not None:
+                accessioner.cloud_tasks_upload_client.validate_queue_info()
+            accessioner.accession_steps(args.dry_run, force=args.force)
+    elif args.subcommand_name == Subparsers.Info.value:
+        session = DbSession.with_home_dir_db_path()
+        db_query = DbQuery(session)
+        info(db_query, args.ids, args.date)
 
 
 if __name__ == "__main__":
